@@ -1,9 +1,8 @@
-niche.overlap <- 
-function(x){
+niche.overlap <- function(x){
 	
 	# CASE 1: x is a pno matrix
 	# -------------------------
-	if (class(x) == "data.frame"){
+	if ( is.data.frame(x) ){
 		x <- x[, -1]
 		nspec <- ncol(x)
 		DI <- matrix(nrow = nspec, ncol = nspec)
@@ -11,15 +10,15 @@ function(x){
 		for (i in 1:(nspec - 1)){
 			for (j in (i + 1):nspec){
 				dhi <- di.pno(x = x[, i], y = x[, j])
-				DI[i, j] <- dhi[1]
-				DI[j, i] <- dhi[2]
+				DI[i, j] <- dhi["D"]
+				DI[j, i] <- dhi["I"]
 			}
 		}
 	}
 
 	## CASE 2: is vector of filenames
 	## ------------------------------
-	if (class(x) == "character"){
+	if ( class(x) == "character" ){
 		nspec <- length(x)
 		DI <- matrix(nrow = nspec, ncol = nspec)
 		rownames(DI) <- colnames(DI) <- x
